pro convert_focas_to_specpro, focas1dfile, focas2dfile, slit=slit, name=name
  
;Wrapper to take FOCAS spectra and convert them to files viewable with the SpecPro interface.
;focas1dfile - fits file with the 1D spectra
;focas2dfile - fits file with the 2D spectra
;name - optional string giving the observation name, to be used in naming output 1d/2d files
;       If not specified, default to "fmos"
;
;Output:
;spec1d, spec2d files viewable by SpecPro.

if n_elements(slit) eq 0 then begin
   slit = 0
endif
if n_elements(name) eq 0 then begin
   name = 'focas'
endif

focas1d = mrdfits(focas1dfile,0,head1)
focas2d = mrdfits(focas2dfile,0,head2)
focas1d = double(focas1d)
focas2d = double(focas2d)

dim_focas1d = size(focas1d)
dim_focas2d = size(focas2d)

num2dypix = dim_focas2d[2] 
numxpix = dim_focas1d[1]

;Calculate the variance (this is a kluge, waiting for real error)
ivar = dblarr(numxpix)
ivar2d = dblarr(numxpix, num2dypix)
for j = 0,numxpix-1 do begin
   var = variance(focas2d[j,*])
   if var ne 0 then begin
      ivar[j] = 1 / var
      ivar2d[j,*] = 1 / var
   endif else begin
      ivar[j]  = 1e20
      ivar2d[j,*] = 1e20
   endelse

   if finite(ivar[j]) eq 0 then ivar[j] = 1e20
endfor

;Create structures to hold the 1d, 2d
focas1dstruct = {flux:dblarr(numxpix), ivar:dblarr(numxpix), lambda:dblarr(numxpix)}
focas2dstruct = {flux:dblarr(numxpix, num2dypix), ivar:dblarr(numxpix, num2dypix), $
                 lambda:dblarr(numxpix, num2dypix)}

focas1dstruct.flux = focas1d
focas2dstruct.flux = focas2d

focas1dstruct.ivar = ivar
focas2dstruct.ivar = ivar2d

;Populate the lambda field
crval1=sxpar(head1,'CRVAL1')
cd = sxpar(head1,'CD1_1')
crpix1 = sxpar(head1,'CRPIX1')
xtemp = findgen(numxpix)
lambda = crval1+cd*(xtemp+1-crpix1)

focas1dstruct.lambda = lambda
focas2dstruct.lambda = rebin(lambda,n_elements(lambda),num2dypix)

;Package the data in specpro format
slit = strcompress(string(slit),/remove_all)
if strlen(slit) eq 1 then begin
   slit = '00'+slit
endif else if strlen(slit) eq 2 then begin
   slit = '0'+slit
endif

;get mask name
splitname = strsplit(focas1dfile,'_',/extract)
maskname = splitname[0]
spec1dname = 'spec1d.'+maskname+'.'+slit+'.'+name+'.fits'
spec2dname = 'spec2d.'+maskname+'.'+slit+'.'+name+'.fits'   

mwrfits, focas1dstruct, spec1dname, /create
mwrfits, focas2dstruct, spec2dname, /create

end ;convert_focas_to_specpro
